@@ -5,10 +5,11 @@ Created on Mon Aug 26 16:12:03 2019
 @author: Reuben
 """
 
+from . import aliases
 from . import utils
 from . import settings
 from . import persist
-from . import container, view
+from . import container
 from . import automate
 from . import namespace
 
@@ -16,7 +17,7 @@ from . import namespace
 from .persist import load, save
 from .namespace import Name_Space, get_container
 from .container import Container
-from .view import View
-from .automate import Automator, Aliases
+from .automate import Automator
+from .aliases import Aliases
 from .utils import Factory, Simple_Factory
 
